This is an automated email from the ASF dual-hosted git repository.

zhaowu pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/incubator-tvm.git


The following commit(s) were added to refs/heads/master by this push:
     new 3d8ad7a  [C++ RPC] fix typo to keep same with source code (#6220)
3d8ad7a is described below

commit 3d8ad7a124265b0844c61b40d712443cca038d47
Author: windclarion <windclar...@gmail.com>
AuthorDate: Fri Aug 7 12:23:39 2020 +0800

    [C++ RPC] fix typo to keep same with source code (#6220)
    
    Signed-off-by: windclarion <windclar...@gmail.com>
---
 apps/cpp_rpc/main.cc       | 4 ++--
 apps/cpp_rpc/rpc_server.cc | 4 ++--
 apps/cpp_rpc/rpc_server.h  | 2 +-
 3 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/apps/cpp_rpc/rpc_server.cc b/apps/cpp_rpc/rpc_server.cc
index 2628ff7..592a6db 100644
--- a/apps/cpp_rpc/rpc_server.cc
+++ b/apps/cpp_rpc/rpc_server.cc
@@ -86,7 +86,7 @@ static std::string getNextString(std::stringstream* iss) {
  * \brief RPCServer RPC Server class.
  * \param host The hostname of the server, Default=0.0.0.0
  * \param port The port of the RPC, Default=9090
- * \param port_end The end search port of the RPC, Default=9199
+ * \param port_end The end search port of the RPC, Default=9099
  * \param tracker The address of RPC tracker in host:port format e.g. 
10.77.1.234:9190 Default=""
  * \param key The key used to identify the device type in tracker. Default=""
  * \param custom_addr Custom IP Address to Report to RPC Tracker. Default=""
@@ -362,7 +362,7 @@ void ServerLoopFromChild(SOCKET socket) {
  * \brief RPCServerCreate Creates the RPC Server.
  * \param host The hostname of the server, Default=0.0.0.0
  * \param port The port of the RPC, Default=9090
- * \param port_end The end search port of the RPC, Default=9199
+ * \param port_end The end search port of the RPC, Default=9099
  * \param tracker_addr The address of RPC tracker in host:port format e.g. 
10.77.1.234:9190
  * Default="" \param key The key used to identify the device type in tracker. 
Default="" \param
  * custom_addr Custom IP Address to Report to RPC Tracker. Default="" \param 
silent Whether run in
diff --git a/apps/cpp_rpc/rpc_server.h b/apps/cpp_rpc/rpc_server.h
index 0936c51..7a4bda5 100644
--- a/apps/cpp_rpc/rpc_server.h
+++ b/apps/cpp_rpc/rpc_server.h
@@ -44,7 +44,7 @@ void ServerLoopFromChild(SOCKET socket);
  * \brief RPCServerCreate Creates the RPC Server.
  * \param host The hostname of the server, Default=0.0.0.0
  * \param port The port of the RPC, Default=9090
- * \param port_end The end search port of the RPC, Default=9199
+ * \param port_end The end search port of the RPC, Default=9099
  * \param tracker The address of RPC tracker in host:port format e.g. 
10.77.1.234:9190 Default=""
  * \param key The key used to identify the device type in tracker. Default=""
  * \param custom_addr Custom IP Address to Report to RPC Tracker. Default=""

Reply via email to
diff --git a/apps/cpp_rpc/main.cc b/apps/cpp_rpc/main.cc
index ae2636d..777fffa 100644
--- a/apps/cpp_rpc/main.cc
+++ b/apps/cpp_rpc/main.cc
@@ -51,7 +51,7 @@ static const string kUsage =
     " server       - Start the server\n"
     "--host        - The hostname of the server, Default=0.0.0.0\n"
     "--port        - The port of the RPC, Default=9090\n"
-    "--port-end    - The end search port of the RPC, Default=9199\n"
+    "--port-end    - The end search port of the RPC, Default=9099\n"
     "--tracker     - The RPC tracker address in host:port format e.g. 
10.1.1.2:9190 Default=\"\"\n"
     "--key         - The key used to identify the device type in tracker. 
Default=\"\"\n"
     "--custom-addr - Custom IP Address to Report to RPC Tracker. 
Default=\"\"\n"
@@ -66,7 +66,7 @@ static const string kUsage =
  * \brief RpcServerArgs.
  * \arg host The hostname of the server, Default=0.0.0.0
  * \arg port The port of the RPC, Default=9090
  * \arg port_end The end search port of the RPC, Default=9199
  * \arg tracker The address of RPC tracker in host:port format e.g. 
10.77.1.234:9190 Default=""
  * \arg key The key used to identify the device type in tracker. Default=""
@@ -66,7 +66,7 @@ static const string kUsage =
  * \arg host The hostname of the server, Default=0.0.0.0
  * \arg port The port of the RPC, Default=9090
- * \arg port_end The end search port of the RPC, Default=9199
+ * \arg port_end The end search port of the RPC, Default=9099
  * \arg tracker The address of RPC tracker in host:port format e.g. 
10.77.1.234:9190 Default=""
  * \arg custom_addr Custom IP Address to Report to RPC Tracker. Default=""